@@ -1,4 +1,3 @@
-from logging import exception
 import os
 import time
 import requests
@@ -242,15 +241,26 @@ class baseWebBrowserController:
             retDataFrame = self.createSearchResultDataFrameAfterProc(retDataFrame, *args, **kwargs)
         except:
             raise Exception
-        finally:
-            if self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.selenium.value:
-                self.wDriver.stop_client()
-                self.wDriver.close()
-                self.wDriver.quit()
             
         # 戻り値を返す
         return retDataFrame
 
+    def quitWebDriver(self):
+        
+        """
+        WebDriver終了処理
+        """
+        
+        if self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.selenium.value:
+
+            # WebDriver終了処理
+            self.browserCtl.wDriver.stop_client()
+            self.browserCtl.wDriver.close()
+            self.browserCtl.wDriver.quit()
+
+            # WebDriver終了処理-ログ出力
+            Logger.logging.info('WebDriver-Quit.')
+            
     @Logger.loggerDecorator('Create SearchResultDataFrame - BeforeProc')
     def createSearchResultDataFrameBeforeProc(self, *args, **kwargs):
         pass
